@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 require File.expand_path("../helper", __FILE__)
 
-class TestRakePathMapPartial < Rake::TestCase
+class TestRakePathMapPartial < Rake::TestCase # :nodoc:
   def test_pathmap_partial
     @path = "1/2/file".dup
     def @path.call(n)
